package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppMyEvaluate;

/**
 * 我的评价Service接口
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
public interface IAppMyEvaluateService 
{
    /**
     * 查询我的评价
     * 
     * @param id 我的评价主键
     * @return 我的评价
     */
    public AppMyEvaluate selectAppMyEvaluateById(Long id);

    /**
     * 查询我的评价列表
     * 
     * @param appMyEvaluate 我的评价
     * @return 我的评价集合
     */
    public List<AppMyEvaluate> selectAppMyEvaluateList(AppMyEvaluate appMyEvaluate);

    /**
     * 新增我的评价
     * 
     * @param appMyEvaluate 我的评价
     * @return 结果
     */
    public int insertAppMyEvaluate(AppMyEvaluate appMyEvaluate);

    /**
     * 修改我的评价
     * 
     * @param appMyEvaluate 我的评价
     * @return 结果
     */
    public int updateAppMyEvaluate(AppMyEvaluate appMyEvaluate);

    /**
     * 批量删除我的评价
     * 
     * @param ids 需要删除的我的评价主键集合
     * @return 结果
     */
    public int deleteAppMyEvaluateByIds(Long[] ids);

    /**
     * 删除我的评价信息
     * 
     * @param id 我的评价主键
     * @return 结果
     */
    public int deleteAppMyEvaluateById(Long id);

    /**
     * 查询我的评价
     *
     * @param id 我的评价主键
     * @return 我的评价
     */
    public List<AppMyEvaluate> getAppMyEvaluateByPetId(Long petId);
}
