package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppMyEvaluate;
import com.ruoyi.model.service.IAppMyEvaluateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 我的评价Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/AppMyEvaluate")
public class AppMyEvaluateController extends BaseController
{
    @Autowired
    private IAppMyEvaluateService appMyEvaluateService;

    /**
     * 查询我的评价列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppMyEvaluate:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppMyEvaluate appMyEvaluate)
    {
        startPage();
        List<AppMyEvaluate> list = appMyEvaluateService.selectAppMyEvaluateList(appMyEvaluate);
        return getDataTable(list);
    }

    /**
     * 导出我的评价列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppMyEvaluate:export')")
    @Log(title = "我的评价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppMyEvaluate appMyEvaluate) throws IOException {
        List<AppMyEvaluate> list = appMyEvaluateService.selectAppMyEvaluateList(appMyEvaluate);
        ExcelUtil<AppMyEvaluate> util = new ExcelUtil<AppMyEvaluate>(AppMyEvaluate.class);
        util.exportExcel(response, list, "我的评价数据");
    }

    /**
     * 获取我的评价详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppMyEvaluate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appMyEvaluateService.selectAppMyEvaluateById(id));
    }

    /**
     * 新增我的评价
     */
    @PreAuthorize("@ss.hasPermi('model:AppMyEvaluate:add')")
    @Log(title = "我的评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppMyEvaluate appMyEvaluate)
    {
        return toAjax(appMyEvaluateService.insertAppMyEvaluate(appMyEvaluate));
    }

    /**
     * 修改我的评价
     */
    @PreAuthorize("@ss.hasPermi('model:AppMyEvaluate:edit')")
    @Log(title = "我的评价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppMyEvaluate appMyEvaluate)
    {
        return toAjax(appMyEvaluateService.updateAppMyEvaluate(appMyEvaluate));
    }

    /**
     * 删除我的评价
     */
    @PreAuthorize("@ss.hasPermi('model:AppMyEvaluate:remove')")
    @Log(title = "我的评价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appMyEvaluateService.deleteAppMyEvaluateByIds(ids));
    }
}
